@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -21,7 +19,6 @@ from oslo.config import cfg
 
 from tuskar.common import paths
 from tuskar.openstack.common.db.sqlalchemy import session as db_session
-from tuskar.openstack.common import rpc
 from tuskar import version
 
 _DEFAULT_SQL_CONNECTION = 'sqlite:///' + paths.state_path_def('$sqlite_db')
@@ -30,8 +27,7 @@ _DEFAULT_SQL_CONNECTION = 'sqlite:///' + paths.state_path_def('$sqlite_db')
 def parse_args(argv, default_config_files=None):
     db_session.set_defaults(sql_connection=_DEFAULT_SQL_CONNECTION,
                             sqlite_db='tuskar.sqlite')
-    rpc.set_defaults(control_exchange='tuskar')
     cfg.CONF(argv[1:],
              project='tuskar',
-             version=version.version_string(),
+             version=version.version_info.release_string(),
              default_config_files=default_config_files)
