@@ -37,31 +37,6 @@ CONF = cfg.CONF
 CONF.register_opts(exc_log_opts)
 
 
-class ProcessExecutionError(IOError):
-    def __init__(self, stdout=None, stderr=None, exit_code=None, cmd=None,
-                 description=None):
-        self.exit_code = exit_code
-        self.stderr = stderr
-        self.stdout = stdout
-        self.cmd = cmd
-        self.description = description
-
-        if description is None:
-            description = _('Unexpected error while running command.')
-        if exit_code is None:
-            exit_code = '-'
-        message = _(
-            '%(description)s\nCommand: %(cmd)s\n'
-            'Exit code: %(exit_code)s\nStdout: %(stdout)r\n'
-            'Stderr: %(stderr)r'
-        ) % {
-            'description': description, 'cmd': cmd,
-            'exit_code': exit_code, 'stdout': stdout,
-            'stderr': stderr
-        }
-        IOError.__init__(self, message)
-
-
 def _cleanse_dict(original):
     """Strip all admin_password, new_pass, rescue_pass keys from a dict."""
     return dict((k, v) for k, v in original.iteritems() if "_pass" not in k)
